@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-column-specification.c - Savable specification of a column.
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -24,8 +24,8 @@
 #include <config.h>
 #include <stdlib.h>
 #include <gtk/gtksignal.h>
-#include <parser.h>
-#include <xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include "gal/util/e-xml-utils.h"
 #include "gal/util/e-util.h"
 #include "e-table-column-specification.h"
@@ -38,9 +38,13 @@ static void
 free_strings (ETableColumnSpecification *etcs)
 {
 	g_free(etcs->title);
+	etcs->title = NULL;
 	g_free(etcs->pixbuf);
+	etcs->pixbuf = NULL;
 	g_free(etcs->cell);
+	etcs->cell = NULL;
 	g_free(etcs->compare);
+	etcs->compare = NULL;
 }
 
 static void
@@ -65,7 +69,7 @@ static void
 etcs_init (ETableColumnSpecification *specification)
 {
 	specification->model_col     = 0;
-	specification->title         = g_strdup("");
+	specification->title        = g_strdup("");
 	specification->pixbuf        = NULL;
 	
 	specification->expansion     = 0;
@@ -94,17 +98,17 @@ e_table_column_specification_load_from_node (ETableColumnSpecification *etcs,
 {
 	free_strings(etcs);
 
-	etcs->model_col     = e_xml_get_integer_prop_by_name (node, "model_col");
-	etcs->title         = e_xml_get_string_prop_by_name (node, "_title");
-	etcs->pixbuf        = e_xml_get_string_prop_by_name (node, "pixbuf");
+	etcs->model_col     = e_xml_get_integer_prop_by_name(node, "model_col");
+	etcs->title         = e_xml_get_string_prop_by_name(node, "_title");
+	etcs->pixbuf        = e_xml_get_string_prop_by_name(node, "pixbuf");
 
-	etcs->expansion     = e_xml_get_double_prop_by_name (node, "expansion");
-	etcs->minimum_width = e_xml_get_integer_prop_by_name (node, "minimum_width");
-	etcs->resizable     = e_xml_get_bool_prop_by_name (node, "resizable");
+	etcs->expansion     = e_xml_get_double_prop_by_name(node, "expansion");
+	etcs->minimum_width = e_xml_get_integer_prop_by_name(node, "minimum_width");
+	etcs->resizable     = e_xml_get_bool_prop_by_name(node, "resizable");
 	etcs->disabled      = e_xml_get_bool_prop_by_name (node, "disabled");
 
-	etcs->cell          = e_xml_get_string_prop_by_name (node, "cell");
-	etcs->compare       = e_xml_get_string_prop_by_name (node, "compare");
+	etcs->cell          = e_xml_get_string_prop_by_name(node, "cell");
+	etcs->compare       = e_xml_get_string_prop_by_name(node, "compare");
 	etcs->priority      = e_xml_get_integer_prop_by_name_with_default (node, "priority", 0);
 
 	if (etcs->title == NULL)
