@@ -24,7 +24,8 @@
 
 #include <config.h>
 #include <string.h>
-#include <glib-object.h>
+#include <gtk/gtkobject.h>
+#include <gtk/gtksignal.h>
 #include <gtk/gtkimage.h>
 #include <gal/util/e-util.h>
 #include "e-table-header.h"
@@ -33,16 +34,15 @@
 
 /* The arguments we take */
 enum {
-	PROP_0,
-	PROP_SORT_INFO,
-	PROP_WIDTH,
-	PROP_WIDTH_EXTRAS
+	ARG_0,
+	ARG_SORT_INFO,
+	ARG_WIDTH,
+	ARG_WIDTH_EXTRAS,
 };
 
 enum {
 	STRUCTURE_CHANGE,
 	DIMENSION_CHANGE,
-	EXPANSION_CHANGE,
 	REQUEST_WIDTH,
 	LAST_SIGNAL
 };
@@ -52,7 +52,7 @@ static void eth_calc_widths (ETableHeader *eth);
 
 static guint eth_signals [LAST_SIGNAL] = { 0, };
 
-static GObjectClass *e_table_header_parent_class;
+static GtkObjectClass *e_table_header_parent_class;
 
 struct two_ints {
 	int column;
@@ -135,7 +135,7 @@ static void
 eth_do_remove (ETableHeader *eth, int idx, gboolean do_unref)
 {
 	if (do_unref)
-		g_object_unref (eth->columns [idx]);
+		gtk_object_unref (GTK_OBJECT (eth->columns [idx]));
 	
 	memmove (&eth->columns [idx], &eth->columns [idx+1],
 		 sizeof (ETableCol *) * (eth->col_count - idx - 1));
@@ -143,7 +143,7 @@ eth_do_remove (ETableHeader *eth, int idx, gboolean do_unref)
 }
 
 static void
-eth_finalize (GObject *object)
+eth_destroy (GtkObject *object)
 {
 	ETableHeader *eth = E_TABLE_HEADER (object);
 	const int cols = eth->col_count;
@@ -151,9 +151,9 @@ eth_finalize (GObject *object)
 	
 	if (eth->sort_info) {
 		if (eth->sort_info_group_change_id)
-			g_signal_handler_disconnect(G_OBJECT(eth->sort_info),
-					            eth->sort_info_group_change_id);
-		g_object_unref(eth->sort_info);
+			gtk_signal_disconnect(GTK_OBJECT(eth->sort_info),
+					      eth->sort_info_group_change_id);
+		gtk_object_unref(GTK_OBJECT(eth->sort_info));
 		eth->sort_info = NULL;
 	}
 
@@ -178,8 +178,8 @@ eth_finalize (GObject *object)
 	eth->col_count = 0;
 	eth->columns = NULL;
 
-	if (e_table_header_parent_class->finalize)
-		e_table_header_parent_class->finalize (object);
+	if (e_table_header_parent_class->destroy)
+		e_table_header_parent_class->destroy (object);
 }
 
 static void
@@ -189,31 +189,31 @@ eth_group_info_changed(ETableSortInfo *info, ETableHeader *eth)
 }
 
 static void
-eth_set_property (GObject *object, guint prop_id, const GValue *val, GParamSpec *pspec)
+eth_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	ETableHeader *eth = E_TABLE_HEADER (object);
 
-	switch (prop_id) {
-	case PROP_WIDTH:
-		eth->nominal_width = g_value_get_double (val);
+	switch (arg_id) {
+	case ARG_WIDTH:
+		eth->nominal_width = GTK_VALUE_DOUBLE (*arg);
+		enqueue(eth, -1, GTK_VALUE_DOUBLE (*arg));
+		break;
+	case ARG_WIDTH_EXTRAS:
+		eth->width_extras = GTK_VALUE_DOUBLE (*arg);
 		enqueue(eth, -1, eth->nominal_width);
 		break;
-	case PROP_WIDTH_EXTRAS:
-		eth->width_extras = g_value_get_double (val);
-		enqueue(eth, -1, eth->nominal_width);
-		break;
-	case PROP_SORT_INFO:
+	case ARG_SORT_INFO:
 		if (eth->sort_info) {
 			if (eth->sort_info_group_change_id)
-				g_signal_handler_disconnect(G_OBJECT(eth->sort_info), eth->sort_info_group_change_id);
-			g_object_unref (eth->sort_info);
+				gtk_signal_disconnect(GTK_OBJECT(eth->sort_info), eth->sort_info_group_change_id);
+			gtk_object_unref(GTK_OBJECT(eth->sort_info));
 		}
-		eth->sort_info = E_TABLE_SORT_INFO(g_value_get_object (val));
+		eth->sort_info = E_TABLE_SORT_INFO(GTK_VALUE_OBJECT (*arg));
 		if (eth->sort_info) {
-			g_object_ref(eth->sort_info);
+			gtk_object_ref(GTK_OBJECT(eth->sort_info));
 			eth->sort_info_group_change_id 
-				= g_signal_connect(G_OBJECT(eth->sort_info), "group_info_changed",
-						   G_CALLBACK(eth_group_info_changed), eth);
+				= gtk_signal_connect(GTK_OBJECT(eth->sort_info), "group_info_changed",
+						     GTK_SIGNAL_FUNC(eth_group_info_changed), eth);
 		}
 		enqueue(eth, -1, eth->nominal_width);
 		break;
@@ -223,92 +223,66 @@ eth_set_property (GObject *object, guint prop_id, const GValue *val, GParamSpec
 }
 
 static void
-eth_get_property (GObject *object, guint prop_id, GValue *val, GParamSpec *pspec)
+eth_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	ETableHeader *eth = E_TABLE_HEADER (object);
 
-	switch (prop_id) {
-	case PROP_SORT_INFO:
-		g_value_set_object (val, G_OBJECT(eth->sort_info));
+	switch (arg_id) {
+	case ARG_SORT_INFO:
+		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(eth->sort_info);
 		break;
-	case PROP_WIDTH:
-		g_value_set_double (val, eth->nominal_width);
+	case ARG_WIDTH:
+		GTK_VALUE_DOUBLE (*arg) = eth->nominal_width;
 		break;
-	case PROP_WIDTH_EXTRAS:
-		g_value_set_double (val, eth->width_extras);
+	case ARG_WIDTH_EXTRAS:
+		GTK_VALUE_DOUBLE (*arg) = eth->width_extras;
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		arg->type = GTK_TYPE_INVALID;
 		break;
 	}
 }
 
 static void
-e_table_header_class_init (GObjectClass *object_class)
+e_table_header_class_init (GtkObjectClass *object_class)
 {
-	ETableHeaderClass *klass = E_TABLE_HEADER_CLASS (object_class);
+	object_class->destroy = eth_destroy;
+	object_class->set_arg = eth_set_arg;
+	object_class->get_arg = eth_get_arg;
 
-	object_class->finalize = eth_finalize;
-	object_class->set_property = eth_set_property;
-	object_class->get_property = eth_get_property;
 
-	e_table_header_parent_class = g_type_class_peek_parent (object_class);
+	e_table_header_parent_class = (gtk_type_class (gtk_object_get_type ()));
 
-	g_object_class_install_property (
-		object_class, PROP_WIDTH,
-		g_param_spec_double ("width", "Width", "Width", 
-				     0.0, G_MAXDOUBLE, 0.0, 
-				     G_PARAM_READWRITE)); 
-
-	g_object_class_install_property (
-		object_class, PROP_WIDTH_EXTRAS,
-		g_param_spec_double ("width_extras", "Width of Extras", "Width of Extras", 
-				     0.0, G_MAXDOUBLE, 0.0, 
-				     G_PARAM_READWRITE)); 
-
-	g_object_class_install_property (
-		object_class, PROP_SORT_INFO,
-		g_param_spec_object ("sort_info", "Sort Info", "Sort Info", 
-				     E_TABLE_SORT_INFO_TYPE,
-				     G_PARAM_READWRITE)); 
+	gtk_object_add_arg_type ("ETableHeader::width", GTK_TYPE_DOUBLE, 
+				 GTK_ARG_READWRITE, ARG_WIDTH); 
+	gtk_object_add_arg_type ("ETableHeader::width_extras", GTK_TYPE_DOUBLE, 
+				 GTK_ARG_READWRITE, ARG_WIDTH_EXTRAS); 
+	gtk_object_add_arg_type ("ETableHeader::sort_info", GTK_TYPE_OBJECT, 
+				 GTK_ARG_READWRITE, ARG_SORT_INFO); 
 
 	eth_signals [STRUCTURE_CHANGE] =
-		g_signal_new ("structure_change",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableHeaderClass, structure_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("structure_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableHeaderClass, structure_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 	eth_signals [DIMENSION_CHANGE] = 
-		g_signal_new ("dimension_change", 
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableHeaderClass, dimension_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
-	eth_signals [EXPANSION_CHANGE] = 
-		g_signal_new ("expansion_change", 
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableHeaderClass, expansion_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("dimension_change", 
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableHeaderClass, dimension_change),
+				gtk_marshal_NONE__INT,
+				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 	eth_signals [REQUEST_WIDTH] = 
-		g_signal_new ("request_width",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableHeaderClass, request_width),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_INT__INT,
-			      G_TYPE_INT, 1, G_TYPE_INT);
+		gtk_signal_new ("request_width",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableHeaderClass, request_width),
+				e_marshal_INT__INT,
+				GTK_TYPE_INT, 1, GTK_TYPE_INT);
 
-	klass->structure_change = NULL;
-	klass->dimension_change = NULL;
-	klass->expansion_change = NULL;
-	klass->request_width = NULL;
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, eth_signals, LAST_SIGNAL);
 }
 
 static void
@@ -336,8 +310,11 @@ e_table_header_init (ETableHeader *eth)
 ETableHeader *
 e_table_header_new (void)
 {
+	ETableHeader *eth;
 
-	return (ETableHeader *) g_object_new (E_TABLE_HEADER_TYPE, NULL);
+	eth = gtk_type_new (e_table_header_get_type ());
+
+	return eth;
 }
 
 static void
@@ -393,12 +370,13 @@ e_table_header_add_column (ETableHeader *eth, ETableCol *tc, int pos)
 	/*
 	 * We are the primary owners of the column
 	 */
-	g_object_ref (tc);
+	gtk_object_ref (GTK_OBJECT (tc));
+	gtk_object_sink (GTK_OBJECT (tc));
 	
 	eth_do_insert (eth, pos, tc);
 
 	enqueue(eth, -1, eth->nominal_width);
-	g_signal_emit (G_OBJECT (eth), eth_signals [STRUCTURE_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (eth), eth_signals [STRUCTURE_CHANGE]);
 }
 
 /**
@@ -521,7 +499,7 @@ e_table_header_get_index_at (ETableHeader *eth, int x_offset)
  * contained in the ETableHeader @eth.  Note that every
  * returned ETableCol in the array has been referenced, to release
  * this information you need to g_free the buffer returned
- * and you need to g_object_unref every element returned
+ * and you need to gtk_object_unref every element returned
  */
 ETableCol **
 e_table_header_get_columns (ETableHeader *eth)
@@ -537,7 +515,7 @@ e_table_header_get_columns (ETableHeader *eth)
 	ret [eth->col_count] = NULL;
 
 	for (i = 0; i < eth->col_count; i++) {
-		g_object_ref(ret[i]);
+		gtk_object_ref(GTK_OBJECT(ret[i]));
 	}
 
 	return ret;
@@ -588,27 +566,6 @@ e_table_header_total_width (ETableHeader *eth)
 	return total;
 }
 
-/**
- * e_table_header_min_width:
- * @eth: The ETableHeader to query
- *
- * Returns: the minimum number of pixels required by the @eth object.
- **/
-int
-e_table_header_min_width (ETableHeader *eth)
-{
-	int total, i;
-	
-	g_return_val_if_fail (eth != NULL, 0);
-	g_return_val_if_fail (E_IS_TABLE_HEADER (eth), 0);
-
-	total = 0;
-	for (i = 0; i < eth->col_count; i++)
-		total += eth->columns [i]->min_width;
-
-	return total;
-}
-
 /**
  * e_table_header_move:
  * @eth: The ETableHeader to operate on.
@@ -639,8 +596,8 @@ e_table_header_move (ETableHeader *eth, int source_index, int target_index)
 	eth_do_insert (eth, target_index, old);
 	eth_update_offsets (eth);
 	
-	g_signal_emit (G_OBJECT (eth), eth_signals [DIMENSION_CHANGE], 0, eth->width);
-	g_signal_emit (G_OBJECT (eth), eth_signals [STRUCTURE_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (eth), eth_signals [DIMENSION_CHANGE]);
+	gtk_signal_emit (GTK_OBJECT (eth), eth_signals [STRUCTURE_CHANGE]);
 }
 
 /**
@@ -661,7 +618,7 @@ e_table_header_remove (ETableHeader *eth, int idx)
 
 	eth_do_remove (eth, idx, TRUE);
 	enqueue(eth, -1, eth->nominal_width);
-	g_signal_emit (G_OBJECT (eth), eth_signals [STRUCTURE_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (eth), eth_signals [STRUCTURE_CHANGE]);
 }
 
 /*
@@ -731,8 +688,6 @@ eth_set_size (ETableHeader *eth, int idx, int size)
 		for (i = idx + 1; i < eth->col_count; i++) {
 			eth->columns[i]->expansion = 0;
 		}
-
-		g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 		return;
 	}
 
@@ -742,7 +697,6 @@ eth_set_size (ETableHeader *eth, int idx, int size)
 		for (i = idx; i < eth->col_count; i++) {
 			eth->columns[i]->expansion = 0;
 		}
-		g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 		return;
 	}
 
@@ -759,7 +713,6 @@ eth_set_size (ETableHeader *eth, int idx, int size)
 		for (i = idx + 1; i < eth->col_count; i++) {
 			eth->columns[i]->expansion = 0;
 		}
-		g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 		return;
 	}
 	
@@ -784,7 +737,6 @@ eth_set_size (ETableHeader *eth, int idx, int size)
 				eth->columns[i]->expansion = expansion / expandable_count;
 			}
 		}
-		g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 		return;
 	}
 
@@ -796,7 +748,6 @@ eth_set_size (ETableHeader *eth, int idx, int size)
 			eth->columns[i]->expansion *= expansion / old_expansion;
 		}
 	}
-	g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 }
 
 /**
@@ -842,11 +793,6 @@ eth_calc_widths (ETableHeader *eth)
 	int last_position = 0;
 	double next_position = 0;
 	int last_resizable = -1;
-	int *widths;
-	gboolean changed;
-
-	widths = g_new (int, eth->col_count);
-
 	/* - 1 to account for the last pixel border. */
 	extra = eth->width - 1;
 	expansion = 0;
@@ -855,31 +801,21 @@ eth_calc_widths (ETableHeader *eth)
 		if (eth->columns[i]->resizable && eth->columns[i]->expansion > 0)
 			last_resizable = i;
 		expansion += eth->columns[i]->resizable ? eth->columns[i]->expansion : 0;
-		widths[i] = eth->columns[i]->min_width + eth->width_extras;
+		eth->columns[i]->width = eth->columns[i]->min_width + eth->width_extras;
 	}
 	if (eth->sort_info)
 		extra -= e_table_sort_info_grouping_get_count(eth->sort_info) * GROUP_INDENT;
 	if (expansion != 0 && extra > 0) {
 		for (i = 0; i < last_resizable; i++) {
 			next_position += extra * (eth->columns[i]->resizable ? eth->columns[i]->expansion : 0)/expansion;
-			widths[i] += next_position - last_position;
+			eth->columns[i]->width += next_position - last_position;
 			last_position = next_position;
 		}
-		widths[i] += extra - last_position;
+		eth->columns[i]->width += extra - last_position;
 	}
 
-	changed = FALSE;
-
-	for (i = 0; i < eth->col_count; i++) {
-		if (eth->columns[i]->width != widths[i]) {
-			changed = TRUE;
-			eth->columns[i]->width = widths[i];
-		}
-	}
-	g_free (widths);
-	if (changed)
-		g_signal_emit (G_OBJECT (eth), eth_signals [DIMENSION_CHANGE], 0, eth->width);
 	eth_update_offsets (eth);
+	gtk_signal_emit (GTK_OBJECT (eth), eth_signals [DIMENSION_CHANGE]);
 }
 
 void
@@ -893,17 +829,37 @@ e_table_header_update_horizontal (ETableHeader *eth)
 	for (i = 0; i < cols; i++) {
 		int width = 0;
 		
-		g_signal_emit_by_name (G_OBJECT (eth),
+		gtk_signal_emit_by_name (GTK_OBJECT (eth),
 					 "request_width",
 					 i, &width);
 		eth->columns[i]->min_width = width + 10;
 		eth->columns[i]->expansion = 1;
 	}
 	enqueue(eth, -1, eth->nominal_width);
-	g_signal_emit (G_OBJECT (eth), eth_signals [EXPANSION_CHANGE], 0);
 }
 
-E_MAKE_TYPE(e_table_header, "ETableHeader", ETableHeader, e_table_header_class_init, e_table_header_init, G_TYPE_OBJECT)
+GtkType
+e_table_header_get_type (void)
+{
+	static GtkType type = 0;
+
+	if (!type){
+		GtkTypeInfo info = {
+			"ETableHeader",
+			sizeof (ETableHeader),
+			sizeof (ETableHeaderClass),
+			(GtkClassInitFunc) e_table_header_class_init,
+			(GtkObjectInitFunc) e_table_header_init,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (gtk_object_get_type (), &info);
+	}
+
+	return type;
+}
 
 int
 e_table_header_prioritized_column (ETableHeader *eth)
@@ -927,26 +883,3 @@ e_table_header_prioritized_column (ETableHeader *eth)
 	}
 	return best_model_col;
 }
-
-ETableCol *
-e_table_header_prioritized_column_selected (ETableHeader *eth, ETableColCheckFunc check_func, gpointer user_data)
-{
-	ETableCol *best_col = NULL;
-	int best_priority = G_MININT;
-	int i;
-	int count;
-
-	count = e_table_header_count (eth);
-	if (count == 0)
-		return NULL;
-	for (i = 1; i < count; i++) {
-		ETableCol *col = e_table_header_get_column (eth, i);
-		if (col) {
-			if ((best_col == NULL || col->priority > best_priority) && check_func (col, user_data)) {
-				best_priority = col->priority;
-				best_col = col;
-			}
-		}
-	}
-	return best_col;
-}
