@@ -24,23 +24,24 @@
 #ifndef _E_TABLE_MODEL_H_
 #define _E_TABLE_MODEL_H_
 
-#include <glib-object.h>
+#include <gtk/gtkobject.h>
 
-G_BEGIN_DECLS
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
 
 #define E_TABLE_MODEL_TYPE        (e_table_model_get_type ())
-#define E_TABLE_MODEL(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_MODEL_TYPE, ETableModel))
-#define E_TABLE_MODEL_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_MODEL_TYPE, ETableModelClass))
-#define E_IS_TABLE_MODEL(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_MODEL_TYPE))
-#define E_IS_TABLE_MODEL_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_MODEL_TYPE))
-#define E_TABLE_MODEL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS((o), E_TABLE_MODEL_TYPE, ETableModelClass))
+#define E_TABLE_MODEL(o)          (GTK_CHECK_CAST ((o), E_TABLE_MODEL_TYPE, ETableModel))
+#define E_TABLE_MODEL_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_MODEL_TYPE, ETableModelClass))
+#define E_IS_TABLE_MODEL(o)       (GTK_CHECK_TYPE ((o), E_TABLE_MODEL_TYPE))
+#define E_IS_TABLE_MODEL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_MODEL_TYPE))
 
 typedef struct {
-	GObject   base;
+	GtkObject   base;
 } ETableModel;
 
 typedef struct {
-	GObjectClass parent_class;
+	GtkObjectClass parent_class;
 
 	/*
 	 * Virtual methods
@@ -93,7 +94,7 @@ typedef struct {
 	void        (*model_rows_deleted)  (ETableModel *etm, int row, int count);
 } ETableModelClass;
 
-GType       e_table_model_get_type            (void);
+GtkType     e_table_model_get_type            (void);
 
 /**/
 int         e_table_model_column_count        (ETableModel *e_table_model);
@@ -165,6 +166,8 @@ int          row);
 void        e_table_model_row_deleted         (ETableModel *e_table_model,
 int          row);
 
-G_END_DECLS
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* _E_TABLE_MODEL_H_ */
