@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-sorted.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -53,21 +53,24 @@ ets_destroy (GtkObject *object)
 {
 	ETableSorted *ets = E_TABLE_SORTED (object);
 
-	if (ets->sort_idle_id) {
+	if (ets->sort_idle_id)
 		g_source_remove(ets->sort_idle_id);
-	}
-	if (ets->insert_idle_id) {
+	ets->sort_idle_id = 0;
+
+	if (ets->insert_idle_id)
 		g_source_remove(ets->insert_idle_id);
-	}
+	ets->insert_idle_id = 0;
 
 	if (ets->sort_info) {
 		gtk_signal_disconnect (GTK_OBJECT (ets->sort_info),
 				       ets->sort_info_changed_id);
 		gtk_object_unref(GTK_OBJECT(ets->sort_info));
+		ets->sort_info = NULL;
 	}
 
 	if (ets->full_header)
 		gtk_object_unref(GTK_OBJECT(ets->full_header));
+	ets->full_header = NULL;
 
 	GTK_OBJECT_CLASS (ets_parent_class)->destroy (object);
 }
@@ -100,7 +103,7 @@ ets_init (ETableSorted *ets)
 	ets->insert_count = 0;
 }
 
-E_MAKE_TYPE(e_table_sorted, "ETableSorted", ETableSorted, ets_class_init, ets_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_sorted, "ETableSorted", ETableSorted, ets_class_init, ets_init, PARENT_TYPE);
 
 static gboolean
 ets_sort_idle(ETableSorted *ets)
@@ -210,10 +213,10 @@ ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row,
 
 	if (row != etss->n_map) {
 		full_change = TRUE;
-		for (i = 0; i < etss->n_map; i++) {
+	for (i = 0; i < etss->n_map; i++) {
 			if (etss->map_table[i] >= row) {
-				etss->map_table[i] += count;
-			}
+			etss->map_table[i] += count;
+	}
 		}
 	}
 
@@ -242,7 +245,7 @@ ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row,
 		etss->map_table[i] = row;
 		etss->n_map++;
 		if (!full_change) {
-			e_table_model_row_inserted (etm, i);
+		e_table_model_row_inserted (etm, i);
 		}
 
 		d(g_print("inserted row %d", row));
@@ -264,12 +267,12 @@ ets_proxy_model_rows_deleted (ETableSubset *etss, ETableModel *source, int row,
 	int j;
 
 	shift = row == etss->n_map - count;
-
+	
 	for (j = 0; j < count; j++) {
 		for (i = 0; i < etss->n_map; i++){
 			if (etss->map_table[i] == row + j) {
 				if (shift)
-					e_table_model_pre_change (etm);
+				e_table_model_pre_change (etm);
 				memmove (etss->map_table + i, etss->map_table + i + 1, (etss->n_map - i - 1) * sizeof(int));
 				etss->n_map --;
 				if (shift)
