@@ -29,7 +29,7 @@
 #include <gal/e-table/e-table-specification.h>
 #include <gal/e-table/e-table-extras.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 ETableHeader *e_table_state_to_header            (GtkWidget           *widget,
 						  ETableHeader        *full_header,
@@ -38,7 +38,7 @@ ETableHeader *e_table_state_to_header            (GtkWidget           *widget,
 ETableHeader *e_table_spec_to_full_header        (ETableSpecification *spec,
 						  ETableExtras        *ete);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_UTILS_H_ */
 
