@@ -21,27 +21,15 @@
  * 02111-1307, USA.
  */
 
-
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "e-xml-utils.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <locale.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
 #include <math.h>
 #include <string.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
-
 #include "gal/util/e-i18n.h"
 #include "gal/util/e-util.h"
 
@@ -100,7 +88,7 @@ e_xml_get_child_by_name_by_lang (const xmlNode *parent,
 static xmlNode *
 e_xml_get_child_by_name_by_lang_list_with_score (const xmlNode *parent,
 						 const gchar *name,
-						 const GList *lang_list,
+						 GList *lang_list,
 						 gint *best_lang_score)
 {
 	xmlNodePtr best_node = NULL, node;
@@ -113,7 +101,7 @@ e_xml_get_child_by_name_by_lang_list_with_score (const xmlNode *parent,
 		}
 		lang = xmlGetProp (node, "xml:lang");
 		if (lang != NULL) {
-			const GList *l;
+			GList *l;
 			gint i;
 
 			for (l = lang_list, i = 0;
@@ -145,7 +133,7 @@ e_xml_get_child_by_name_by_lang_list_with_score (const xmlNode *parent,
 xmlNode *
 e_xml_get_child_by_name_by_lang_list (const xmlNode *parent,
 				      const gchar *name,
-				      const GList *lang_list)
+				      GList *lang_list)
 {
 	gint best_lang_score = INT_MAX;
 
@@ -353,19 +341,15 @@ void
 e_xml_set_double_prop_by_name(xmlNode *parent, const xmlChar *prop_name, gdouble value)
 {
 	char buffer[E_ASCII_DTOSTR_BUF_SIZE];
-	char *format;
 
 	g_return_if_fail (parent != NULL);
 	g_return_if_fail (prop_name != NULL);
 
 	if (fabs (value) < 1e9 && fabs (value) > 1e-5) {
-		format = g_strdup_printf ("%%.%df", DBL_DIG);
+		e_ascii_dtostr (buffer, sizeof (buffer), "%.17f", value);
 	} else {
-		format = g_strdup_printf ("%%.%dg", DBL_DIG);
+		e_ascii_dtostr (buffer, sizeof (buffer), "%.17g", value);
 	}
-	e_ascii_dtostr (buffer, sizeof (buffer), format, value);
-	g_free (format);
-
 	xmlSetProp (parent, prop_name, buffer);
 }
 
@@ -435,68 +419,3 @@ e_xml_get_translated_string_prop_by_name (const xmlNode *parent, const xmlChar *
 
 	return ret_val;
 }
-
-
-int
-e_xml_save_file (const char *filename, xmlDocPtr doc)
-{
-	char *filesave, *slash, *xmlbuf;
-	size_t n, written = 0;
-	int ret, fd, size;
-	int errnosave;
-	ssize_t w;
-	
-	filesave = alloca (strlen (filename) + 5);
-	slash = strrchr (filename, '/');
-	if (slash)
-		sprintf (filesave, "%.*s.#%s", slash - filename + 1, filename, slash + 1);
-	else
-		sprintf (filesave, ".#%s", filename);
-	
-	fd = open (filesave, O_WRONLY | O_CREAT | O_TRUNC, 0600);
-	if (fd == -1)
-		return -1;
-	
-	xmlDocDumpMemory (doc, (xmlChar **) &xmlbuf, &size);
-	if (size <= 0) {
-		close (fd);
-		unlink (filesave);
-		errno = ENOMEM;
-		return -1;
-	}
-	
-	n = (size_t) size;
-	do {
-		do {
-			w = write (fd, xmlbuf + written, n - written);
-		} while (w == -1 && errno == EINTR);
-		
-		if (w > 0)
-			written += w;
-	} while (w != -1 && written < n);
-	
-	xmlFree (xmlbuf);
-	
-	if (written < n || fsync (fd) == -1) {
-		errnosave = errno;
-		close (fd);
-		unlink (filesave);
-		errno = errnosave;
-		return -1;
-	}
-	
-	while ((ret = close (fd)) == -1 && errno == EINTR)
-		;
-	
-	if (ret == -1)
-		return -1;
-	
-	if (rename (filesave, filename) == -1) {
-		errnosave = errno;
-		unlink (filesave);
-		errno = errnosave;
-		return -1;
-	}
-	
-	return 0;
-}
