@@ -21,32 +21,61 @@
  * 02111-1307, USA.
  */
 
-
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "e-gui-utils.h"
 
 #include <gtk/gtkentry.h>
 #include <gtk/gtksignal.h>
+#include <libgnomeui/gnome-messagebox.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 
 void
-e_auto_kill_popup_menu_on_selection_done (GtkMenu *menu)
+e_notice (GtkWindow *window, const char *type, const char *format, ...)
 {
-	g_return_if_fail (GTK_IS_MENU (menu));
+	GtkWidget *dialog;
+	va_list args;
+	char *str;
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	dialog = gnome_message_box_new (str, type, GTK_STOCK_OK, NULL);
+	va_end (args);
+	g_free (str);
 	
-	g_signal_connect (menu, "selection_done", G_CALLBACK (gtk_widget_destroy), menu);
+	if (window)
+		gnome_dialog_set_parent (GNOME_DIALOG (dialog), window);
+
+	gnome_dialog_run (GNOME_DIALOG (dialog));
+}
+
+static void
+kill_popup_menu (GtkWidget *widget, GtkMenu *menu)
+{
+	g_return_if_fail (menu != NULL);
+	g_return_if_fail (GTK_IS_MENU (menu));
+
+	gtk_object_unref (GTK_OBJECT (menu));
+}
+
+void
+e_auto_kill_popup_menu_on_hide (GtkMenu *menu)
+{
+	g_return_if_fail (menu != NULL);
+	g_return_if_fail (GTK_IS_MENU (menu));
+
+	gtk_signal_connect (GTK_OBJECT (menu), "hide",
+			    GTK_SIGNAL_FUNC (kill_popup_menu), menu);
 }
 
 void
 e_popup_menu (GtkMenu *menu, GdkEvent *event)
 {
+	g_return_if_fail (menu != NULL);
 	g_return_if_fail (GTK_IS_MENU (menu));
 
-	e_auto_kill_popup_menu_on_selection_done (menu);
+	e_auto_kill_popup_menu_on_hide (menu);
 
 	if (event->type == GDK_KEY_PRESS)
 		gtk_menu_popup (menu, NULL, NULL, 0, NULL, 0, event->key.time);
@@ -89,7 +118,7 @@ static void
 e_container_change_tab_order_destroy_notify(gpointer data)
 {
 	GList *list = data;
-	g_list_foreach(list, (GFunc) g_object_unref, NULL);
+	g_list_foreach(list, (GFunc) gtk_object_unref, NULL);
 	g_list_free(list);
 }
 
@@ -133,7 +162,8 @@ e_container_change_tab_order_callback(GtkContainer *container,
 				    GTK_IS_CONTAINER (child) &&
 				    !GTK_WIDGET_HAS_FOCUS (child))
 					if (gtk_widget_child_focus (GTK_WIDGET (child), direction)) {
-						g_signal_stop_emission_by_name (container, "focus");
+						gtk_signal_emit_stop_by_name (
+							GTK_OBJECT (container), "focus");
 						return TRUE;
 					}
 			}
@@ -141,13 +171,14 @@ e_container_change_tab_order_callback(GtkContainer *container,
 		else if (GTK_WIDGET_DRAWABLE (child)) {
 			if (GTK_IS_CONTAINER (child)) {
 				if (gtk_widget_child_focus (GTK_WIDGET (child), direction)) {
-					g_signal_stop_emission_by_name (container, "focus");
+					gtk_signal_emit_stop_by_name (
+						GTK_OBJECT (container), "focus");
 					return TRUE;
 				}
 			}
 			else if (GTK_WIDGET_CAN_FOCUS (child)) {
 				gtk_widget_grab_focus (child);
-				g_signal_stop_emission_by_name (container, "focus");
+				gtk_signal_emit_stop_by_name (GTK_OBJECT (container), "focus");
 				return TRUE;
 			}
 		}
@@ -161,7 +192,7 @@ e_container_change_tab_order(GtkContainer *container, GList *widgets)
 {
 	GList *list;
 	list = g_list_copy(widgets);
-	g_list_foreach(list, (GFunc) g_object_ref, NULL);
+	g_list_foreach(list, (GFunc) gtk_object_ref, NULL);
 	return gtk_signal_connect_full(GTK_OBJECT(container), "focus",
 				       GTK_SIGNAL_FUNC(e_container_change_tab_order_callback),
 				       NULL, list,
@@ -199,34 +230,3 @@ e_container_focus_nth_entry(GtkContainer *container, int n)
 	if (data.widget)
 		gtk_widget_grab_focus(data.widget);
 }
-
-gboolean
-e_glade_xml_connect_widget (GladeXML *gui, char *name, char *signal, GCallback cb, gpointer closure)
-{
-	GtkWidget *widget;
-
-	widget = glade_xml_get_widget (gui, name);
-
-	if (widget) {
-		g_signal_connect (widget, signal,
-				  cb, closure);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-gboolean
-e_glade_xml_set_sensitive (GladeXML *gui, char *name, gboolean sensitive)
-{
-	GtkWidget *widget;
-
-	widget = glade_xml_get_widget (gui, name);
-
-	if (widget) {
-		gtk_widget_set_sensitive (widget, sensitive);
-		return TRUE;
-	}
-
-	return FALSE;
-}
