@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-selection-model-array.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -26,7 +26,7 @@
 #include "e-selection-model-array.h"
 #include "gal/util/e-util.h"
 
-#define ESMA_CLASS(e) ((ESelectionModelArrayClass *)((GtkObject *)e)->klass)
+#define ESMA_CLASS(e) ((ESelectionModelArrayClass *)(GTK_OBJECT_GET_CLASS (e)))
 
 #define PARENT_TYPE e_selection_model_get_type ()
 
@@ -35,7 +35,7 @@ static ESelectionModelClass *parent_class;
 enum {
 	ARG_0,
 	ARG_CURSOR_ROW,
-	ARG_CURSOR_COL
+	ARG_CURSOR_COL,
 };
 
 void
@@ -474,8 +474,9 @@ esma_set_selection_end (ESelectionModel *selection, int row)
 		    selected_range_end == view_row + 1) {
 			e_selection_model_selection_row_changed(selection, selected_range_end);
 			e_selection_model_selection_row_changed(selection, view_row);
+			return;
 		}
-	}
+}
 	e_selection_model_selection_changed(selection);
 }
 
@@ -546,4 +547,4 @@ e_selection_model_array_class_init (ESelectionModelArrayClass *klass)
 }
 
 E_MAKE_TYPE(e_selection_model_array, "ESelectionModelArray", ESelectionModelArray,
-	    e_selection_model_array_class_init, e_selection_model_array_init, PARENT_TYPE)
+	    e_selection_model_array_class_init, e_selection_model_array_init, PARENT_TYPE);
