@@ -52,9 +52,6 @@ pixmap_combo_destroy (GtkObject *object)
 		gtk_object_unref (GTK_OBJECT (pc->tool_tip));
 	pc->tool_tip = NULL;
 	
-	g_free (pc->pixmaps);
-	pc->pixmaps = NULL;
-
 	(*pixmap_combo_parent_class->destroy) (object);
 }
 
@@ -120,6 +117,15 @@ pixmap_clicked (GtkWidget *button, PixmapCombo *pc)
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (pc));
 }
 
+static GtkWidget *
+image_from_data (guint8 const *data)
+{
+	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1,  data, FALSE, NULL);
+	GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+	g_object_unref (pixbuf);
+	return image;
+}
+
 static void
 pixmap_table_setup (PixmapCombo *pc)
 {
@@ -130,8 +136,6 @@ pixmap_table_setup (PixmapCombo *pc)
 	gtk_object_ref (GTK_OBJECT (pc->tool_tip));
 	gtk_object_sink (GTK_OBJECT (pc->tool_tip));
 
-	pc->pixmaps = g_malloc (sizeof (GtkWidget *) * pc->cols * pc->rows);
-
 	for (row = 0; row < pc->rows; row++) {
 		for (col = 0; col < pc->cols; ++col, ++index) {
 			PixmapComboElement const *element = pc->elements + index;
@@ -143,20 +147,15 @@ pixmap_table_setup (PixmapCombo *pc)
 				break;
 			}
 
-			pc->pixmaps [index] = gtk_image_new_from_pixbuf (
-				gdk_pixbuf_new_from_inline (-1, 
-					element->inline_gdkpixbuf ,
-					FALSE, NULL));
-
 			button = gtk_button_new ();
-			gtk_button_set_relief (GTK_BUTTON (button),
-					       GTK_RELIEF_NONE);
 			gtk_container_add (GTK_CONTAINER (button),
-					   pc->pixmaps [index]);
+				image_from_data (element->inline_gdkpixbuf));
+			gtk_button_set_relief (GTK_BUTTON (button),
+				GTK_RELIEF_NONE);
 			gtk_tooltips_set_tip (pc->tool_tip,
-					      button,
-					      gettext (element->untranslated_tooltip),
-					      "What goes here ??");
+				button,
+				gettext (element->untranslated_tooltip),
+				"What goes here ??");
 
 			gtk_table_attach (GTK_TABLE (pc->combo_table), button,
 					  col, col+1, row+1, row+2, GTK_FILL, GTK_FILL, 1, 1);
@@ -188,9 +187,7 @@ pixmap_combo_construct (PixmapCombo *pc,
 	pc->preview_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (pc->preview_button), GTK_RELIEF_NONE);
 
-	pc->preview_pixmap = gtk_image_new_from_pixbuf (
-		gdk_pixbuf_new_from_inline (-1, 
-			elements [0].inline_gdkpixbuf , FALSE, NULL));
+	pc->preview_pixmap = image_from_data (elements [0].inline_gdkpixbuf);
 
 	gtk_container_add (GTK_CONTAINER (pc->preview_button), GTK_WIDGET (pc->preview_pixmap));
 	gtk_widget_set_usize (GTK_WIDGET (pc->preview_pixmap), 24, 24);
@@ -235,9 +232,8 @@ pixmap_combo_select_pixmap (PixmapCombo *pc, int index)
 		GTK_CONTAINER (pc->preview_button),
 		pc->preview_pixmap);
 
-	pc->preview_pixmap = gtk_image_new_from_pixbuf (
-		gdk_pixbuf_new_from_inline (-1, 
-			pc->elements [index].inline_gdkpixbuf , FALSE, NULL));
+	pc->preview_pixmap = image_from_data (
+		pc->elements [index].inline_gdkpixbuf);
 	gtk_widget_show (pc->preview_pixmap);
 	
 	gtk_container_add (
